@@ -8,6 +8,7 @@ mod reporter;
 mod result;
 pub mod test;
 pub mod test_runners;
+mod watch;
 
 pub use actions::Action;
 pub use actions::Source;
@@ -16,11 +17,14 @@ pub use actions::TestDataOut;
 pub use errors::Error;
 pub use exec::Executable;
 pub use lang::Language;
-pub use report::Failure;
-pub use report::Report;
-pub use report::TestCase;
-pub use report::TestSuite;
+pub use report::CoreFailure;
+pub use report::CoreReport;
+pub use report::CoreTestCase;
+pub use report::CoreTestSuite;
 pub use reporter::Error as ReporterError;
 pub use reporter::Reporter;
 pub use result::Reason;
 pub use result::TestResult;
+pub use test::xunit::AvailableTests;
+pub use watch::ProvolaWatcher as Watcher;
+pub use watch::WatchOptions;
